check

package
v0.0.0-...-1ed95e1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2025 License: LGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LogAndPanicIfErrf

func LogAndPanicIfErrf(err error, logger logging.Logger, format string, args ...any)

LogAndPanicIfErrf logs the error with the provided logger and message and panics if err is not nil.

func PanicIfErr

func PanicIfErr(err error)

PanicIfErr calls panic(err) if err is not nil.

func PanicIfNot

func PanicIfNot(flag bool)

PanicIfNot panics on false (use as simple assert).

func PanicIfNotCancelledErr

func PanicIfNotCancelledErr(err error)

PanicIfNotCancelledErr panics if the provided error is non-nil and not a context.Canceled error.

func PanicIfNotf

func PanicIfNotf(flag bool, format string, args ...any)

PanicIfNotf panics on false with the given message.

func PanicIff

func PanicIff(flag bool, format string, args ...any)

PanicIff panics on true with the given message.

Types

This section is empty.

Jump to