Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LogAndPanicIfErrf ¶
LogAndPanicIfErrf logs the error with the provided logger and message and panics if err is not nil.
func PanicIfNotCancelledErr ¶
func PanicIfNotCancelledErr(err error)
PanicIfNotCancelledErr panics if the provided error is non-nil and not a context.Canceled error.
func PanicIfNotf ¶
PanicIfNotf panics on false with the given message.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.